import * as tslib_1 from "tslib";
import "./RichEditor.css";
import "trumbowyg/dist/ui/trumbowyg.min.css";
import * as React from "react";
import "trumbowyg/dist/trumbowyg";
import { delay } from "../../Utilities/Core";
import { newGuid } from "../../Utilities/Guid";
import "../../Utilities/PasteImagePlugin";
import { StaticObservable } from "../../Utilities/StaticObservable";
import { isNullOrEmpty } from "../../Utilities/String";
import "../../Utilities/UploadImagePlugin";
import { InfoLabel } from "../InfoLabel";
import { InputError } from "../InputError";
import { BaseFluxComponent } from "../Utilities/BaseFluxComponent";
import { autobind, css } from "OfficeFabric/Utilities";
var RichEditor = (function (_super) {
    tslib_1.__extends(RichEditor, _super);
    function RichEditor() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RichEditor.prototype.focus = function () {
        if (this._richEditorContainer) {
            this._richEditorContainer.focus();
        }
    };
    RichEditor.prototype.componentDidMount = function () {
        _super.prototype.componentDidMount.call(this);
        StaticObservable.getInstance().unsubscribe(this._onImagePaste, "imagepasted");
        StaticObservable.getInstance().subscribe(this._onImagePaste, "imagepasted");
        this._richEditorContainer = $("#" + this._containerId);
        this._richEditorContainer
            .trumbowyg(this.props.editorOptions || {})
            .on("tbwchange", this._onChange)
            .on("tbwblur", this._fireChange);
        this._richEditorContainer.trumbowyg("html", this.props.value || "");
        if (this.props.disabled) {
            this._richEditorContainer.trumbowyg("disable");
        }
    };
    RichEditor.prototype.componentWillUnmount = function () {
        _super.prototype.componentWillUnmount.call(this);
        StaticObservable.getInstance().unsubscribe(this._onImagePaste, "imagepasted");
        this._richEditorContainer.trumbowyg("destroy");
        this._disposeDelayedFunction();
    };
    RichEditor.prototype.componentWillReceiveProps = function (nextProps, context) {
        _super.prototype.componentWillReceiveProps.call(this, nextProps, context);
        this._disposeDelayedFunction();
        if (nextProps.value !== this.state.value) {
            this._richEditorContainer.trumbowyg("html", nextProps.value || "");
            this.setState({
                value: nextProps.value
            });
        }
        if (nextProps.disabled !== this.props.disabled) {
            if (nextProps.disabled) {
                this._richEditorContainer.trumbowyg("disable");
            }
            else {
                this._richEditorContainer.trumbowyg("disable");
            }
        }
    };
    RichEditor.prototype.render = function () {
        var error = this.props.error || this._getDefaultError();
        return (React.createElement("div", { className: css("rich-editor-container", this.props.className) },
            this.props.label && React.createElement(InfoLabel, { className: "rich-editor-label", label: this.props.label, info: this.props.info }),
            React.createElement("div", { className: "progress-bar", style: { visibility: this.state.loading ? "visible" : "hidden" } }),
            React.createElement("div", { id: this._containerId, className: "rich-editor" }),
            error && React.createElement(InputError, { className: "rich-editor-error", error: error })));
    };
    RichEditor.prototype.initializeState = function () {
        this.state = {
            value: this.props.value || ""
        };
        this._containerId = this.props.containerId || newGuid();
    };
    RichEditor.prototype._getDefaultError = function () {
        if (this.props.required && isNullOrEmpty(this.state.value)) {
            return "A value is required";
        }
    };
    RichEditor.prototype._onChange = function () {
        var _this = this;
        this._disposeDelayedFunction();
        if (this.props.delay == null) {
            this._fireChange();
        }
        else {
            this._delayedFunction = delay(this, this.props.delay, function () {
                _this._fireChange();
            });
        }
    };
    RichEditor.prototype._fireChange = function () {
        var _this = this;
        this._disposeDelayedFunction();
        var value = this._richEditorContainer.trumbowyg("html");
        this.setState({ value: value }, function () {
            _this.props.onChange(value);
        });
    };
    RichEditor.prototype._onImagePaste = function (args) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var imageUrl, e_1;
            return tslib_1.__generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!this.props.getPastedImageUrl) {
                            return [2];
                        }
                        this.setState({ loading: true });
                        _a.label = 1;
                    case 1:
                        _a.trys.push([1, 3, , 4]);
                        return [4, this.props.getPastedImageUrl(args.data)];
                    case 2:
                        imageUrl = _a.sent();
                        args.callback(imageUrl);
                        this.setState({ loading: false });
                        return [3, 4];
                    case 3:
                        e_1 = _a.sent();
                        args.callback(null);
                        this.setState({ loading: false });
                        return [3, 4];
                    case 4: return [2];
                }
            });
        });
    };
    RichEditor.prototype._disposeDelayedFunction = function () {
        if (this._delayedFunction) {
            this._delayedFunction.cancel();
            this._delayedFunction = null;
        }
    };
    tslib_1.__decorate([
        autobind
    ], RichEditor.prototype, "_onChange", null);
    tslib_1.__decorate([
        autobind
    ], RichEditor.prototype, "_fireChange", null);
    tslib_1.__decorate([
        autobind
    ], RichEditor.prototype, "_onImagePaste", null);
    return RichEditor;
}(BaseFluxComponent));
export { RichEditor };
//# sourceMappingURL=RichEditor.js.map