import * as tslib_1 from "tslib";
import "./SplitterLayout.css";
import * as React from "react";
import { Pane } from "./Pane";
import { autobind } from "OfficeFabric/Utilities";
function clearSelection() {
    if (window.getSelection) {
        if (window.getSelection().empty) {
            window.getSelection().empty();
        }
        else if (window.getSelection().removeAllRanges) {
            window.getSelection().removeAllRanges();
        }
    }
    else if (document.selection) {
        document.selection.empty();
    }
}
var DEFAULT_SPLITTER_SIZE = 4;
var SplitterLayout = (function (_super) {
    tslib_1.__extends(SplitterLayout, _super);
    function SplitterLayout(props) {
        var _this = _super.call(this, props) || this;
        _this.state = {
            secondaryPaneSize: 0,
            resizing: false
        };
        return _this;
    }
    SplitterLayout.prototype.componentDidMount = function () {
        window.addEventListener("resize", this._handleResize);
        document.addEventListener("mouseup", this._handleMouseUp);
        document.addEventListener("mousemove", this._handleMouseMove);
        var secondaryPaneSize = this.props.secondaryInitialSize;
        if (secondaryPaneSize == null) {
            var containerRect = this._containerElement.getBoundingClientRect();
            var splitRect = void 0;
            if (this._splitterElement) {
                splitRect = this._splitterElement.getBoundingClientRect();
            }
            else {
                splitRect = { width: DEFAULT_SPLITTER_SIZE, height: DEFAULT_SPLITTER_SIZE };
            }
            secondaryPaneSize = this._getSecondaryPaneSize(containerRect, splitRect, {
                left: containerRect.left + ((containerRect.width - splitRect.width) / 2),
                top: containerRect.top + ((containerRect.height - splitRect.height) / 2)
            }, false);
        }
        this.setState({ secondaryPaneSize: secondaryPaneSize });
    };
    SplitterLayout.prototype.componentWillUnmount = function () {
        window.removeEventListener("resize", this._handleResize);
        document.removeEventListener("mouseup", this._handleMouseUp);
        document.removeEventListener("mousemove", this._handleMouseMove);
    };
    SplitterLayout.prototype.render = function () {
        var _this = this;
        var containerClasses = "split-layout";
        if (this.props.customClassName) {
            containerClasses += " " + this.props.customClassName;
        }
        if (this.props.vertical) {
            containerClasses += " split-layout-vertical";
        }
        if (this.state.resizing) {
            containerClasses += " layout-changing";
        }
        var children = React.Children.toArray(this.props.children).slice(0, 2);
        if (children.length === 0) {
            children.push(React.createElement("div", null));
        }
        var wrappedChildren = [];
        var primaryIndex = (this.props.primaryIndex !== 0 && this.props.primaryIndex !== 1) ? 0 : this.props.primaryIndex;
        for (var i = 0; i < children.length; ++i) {
            var primary = true;
            var size = void 0;
            if (children.length > 1 && i !== primaryIndex) {
                primary = false;
                size = this.state.secondaryPaneSize;
            }
            wrappedChildren.push(React.createElement(Pane, { vertical: this.props.vertical, percentage: this.props.percentage, primary: primary, size: size }, children[i]));
        }
        return (React.createElement("div", { className: containerClasses, ref: function (c) { _this._containerElement = c; } },
            wrappedChildren[0],
            wrappedChildren.length > 1 &&
                React.createElement("div", { className: "layout-split", ref: function (c) { _this._splitterElement = c; }, onMouseDown: this._handleSplitterMouseDown }),
            wrappedChildren.length > 1 && wrappedChildren[1]));
    };
    SplitterLayout.prototype._getSecondaryPaneSize = function (containerRect, splitRect, clientPosition, offsetMouse) {
        var totalSize;
        var splitSize;
        var offset;
        if (this.props.vertical) {
            totalSize = containerRect.height;
            splitSize = splitRect.height;
            offset = clientPosition.top - containerRect.top;
        }
        else {
            totalSize = containerRect.width;
            splitSize = splitRect.width;
            offset = clientPosition.left - containerRect.left;
        }
        if (offsetMouse) {
            offset -= splitSize / 2;
        }
        if (offset < 0) {
            offset = 0;
        }
        else if (offset > totalSize - splitSize) {
            offset = totalSize - splitSize;
        }
        var secondaryPaneSize;
        if (this.props.primaryIndex === 1) {
            secondaryPaneSize = offset;
        }
        else {
            secondaryPaneSize = totalSize - splitSize - offset;
        }
        var primaryPaneSize = totalSize - splitSize - secondaryPaneSize;
        if (this.props.percentage) {
            secondaryPaneSize = (secondaryPaneSize * 100) / totalSize;
            primaryPaneSize = (primaryPaneSize * 100) / totalSize;
            splitSize = (splitSize * 100) / totalSize;
            totalSize = 100;
        }
        if (primaryPaneSize < this.props.primaryMinSize) {
            secondaryPaneSize = Math.max(secondaryPaneSize - (this.props.primaryMinSize - primaryPaneSize), 0);
        }
        else if (secondaryPaneSize < this.props.secondaryMinSize) {
            secondaryPaneSize = Math.min(totalSize - splitSize - this.props.primaryMinSize, this.props.secondaryMinSize);
        }
        return secondaryPaneSize;
    };
    SplitterLayout.prototype._handleResize = function () {
        if (this._splitterElement && !this.props.percentage) {
            var containerRect = this._containerElement.getBoundingClientRect();
            var splitRect = this._splitterElement.getBoundingClientRect();
            var secondaryPaneSize = this._getSecondaryPaneSize(containerRect, splitRect, {
                left: splitRect.left,
                top: splitRect.top
            }, false);
            this.setState({ secondaryPaneSize: secondaryPaneSize });
        }
    };
    SplitterLayout.prototype._handleMouseMove = function (e) {
        if (this.state.resizing) {
            var containerRect = this._containerElement.getBoundingClientRect();
            var splitRect = this._splitterElement.getBoundingClientRect();
            var secondaryPaneSize = this._getSecondaryPaneSize(containerRect, splitRect, {
                left: e.clientX,
                top: e.clientY
            }, true);
            clearSelection();
            this.setState({ secondaryPaneSize: secondaryPaneSize });
            if (this.props.onChange) {
                this.props.onChange(secondaryPaneSize);
            }
        }
    };
    SplitterLayout.prototype._handleSplitterMouseDown = function () {
        clearSelection();
        this.setState({ resizing: true });
    };
    SplitterLayout.prototype._handleMouseUp = function () {
        if (this.state.resizing) {
            this.setState({ resizing: false });
        }
    };
    tslib_1.__decorate([
        autobind
    ], SplitterLayout.prototype, "_handleResize", null);
    tslib_1.__decorate([
        autobind
    ], SplitterLayout.prototype, "_handleMouseMove", null);
    tslib_1.__decorate([
        autobind
    ], SplitterLayout.prototype, "_handleSplitterMouseDown", null);
    tslib_1.__decorate([
        autobind
    ], SplitterLayout.prototype, "_handleMouseUp", null);
    return SplitterLayout;
}(React.Component));
export { SplitterLayout };
//# sourceMappingURL=SplitterLayout.js.map