import * as tslib_1 from "tslib";
import * as React from "react";
export var VERTICAL = "VERTICAL";
export var HORIZONTAL = "HORIZONTAL";
var draggingIndex = null;
export function sortable(Comp, flowDirection) {
    if (flowDirection === void 0) { flowDirection = VERTICAL; }
    return (function (_super) {
        tslib_1.__extends(Sortable, _super);
        function Sortable() {
            var _this = _super !== null && _super.apply(this, arguments) || this;
            _this.sortEnd = function (e) {
                e.preventDefault();
                e.stopPropagation();
                draggingIndex = null;
                _this.props.onSortEnd();
            };
            _this.sortStart = function (e) {
                draggingIndex = e.currentTarget.id;
                var dt = e.dataTransfer;
                if (dt !== undefined) {
                    e.dataTransfer.setData("id", e.target.id);
                    if (dt.setDragImage && e.currentTarget.tagName.toLowerCase() === "a") {
                        dt.setDragImage(e.target, 0, 0);
                    }
                }
            };
            _this.dragOver = function (e) {
                e.preventDefault();
                var moveInMiddle = _this.props.moveInMiddle;
                var overEl = e.currentTarget;
                var indexDragged = Number(overEl.id);
                var indexFrom = Number(draggingIndex);
                var height = overEl.getBoundingClientRect().height;
                var width = overEl.getBoundingClientRect().width;
                var positionX = e.clientX;
                var positionY = e.clientY;
                var topOffset = overEl.getBoundingClientRect().top;
                var leftOffset = overEl.getBoundingClientRect().left;
                var mouseBeyond;
                if (flowDirection === VERTICAL) {
                    mouseBeyond = isMouseBeyond(positionY, topOffset, height, moveInMiddle);
                }
                if (flowDirection === HORIZONTAL) {
                    mouseBeyond = isMouseBeyond(positionX, leftOffset, width, moveInMiddle);
                }
                if (indexDragged !== indexFrom && mouseBeyond) {
                    var items = swapArrayElements(_this.props.items, indexFrom, indexDragged);
                    draggingIndex = indexDragged;
                    _this.props.onSortItems(items);
                }
            };
            return _this;
        }
        Sortable.prototype.render = function () {
            var newProps = tslib_1.__assign({}, this.props);
            delete newProps.onSortItems;
            delete newProps.onSortEnd;
            delete newProps.moveInMiddle;
            delete newProps.items;
            var sortId = newProps.sortId, props = tslib_1.__rest(newProps, ["sortId"]);
            return (React.createElement(Comp, tslib_1.__assign({ draggable: true, onDragOver: this.dragOver, onDragStart: this.sortStart, onDragEnd: this.sortEnd, id: sortId }, props)));
        };
        return Sortable;
    }(React.Component));
}
function swapArrayElements(items, indexFrom, indexTo) {
    var item = items[indexTo];
    items[indexTo] = items[indexFrom];
    items[indexFrom] = item;
    return items;
}
function isMouseBeyond(mousePos, elementPos, elementSize, moveInMiddle) {
    var breakPoint;
    if (moveInMiddle) {
        breakPoint = elementSize / 2;
    }
    else {
        breakPoint = 0;
    }
    var mouseOverlap = mousePos - elementPos;
    return mouseOverlap > breakPoint;
}
//# sourceMappingURL=Sortable.js.map