import * as tslib_1 from "tslib";
import "./ThrottledTextField.css";
import * as React from "react";
import { delay } from "../../Utilities/Core";
import { isNullOrEmpty } from "../../Utilities/String";
import { InfoLabel } from "../InfoLabel";
import { InputError } from "../InputError";
import { BaseFluxComponent } from "./BaseFluxComponent";
import { TextField } from "OfficeFabric/TextField";
import { autobind, css } from "OfficeFabric/Utilities";
var ThrottledTextField = (function (_super) {
    tslib_1.__extends(ThrottledTextField, _super);
    function ThrottledTextField() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ThrottledTextField.prototype.focus = function () {
        if (this._component) {
            this._component.focus();
        }
    };
    ThrottledTextField.prototype.render = function () {
        var props = tslib_1.__assign({}, this.props, { value: this.state.internalValue, onChanged: this._onChange, className: "throttled-text-field-text", componentRef: this._refCallback });
        delete props.delay;
        delete props.info;
        delete props.required;
        delete props.errorMessage;
        delete props.label;
        var error = this.props.errorMessage || this._getDefaultError();
        return (React.createElement("div", { className: css("throttled-text-field", this.props.className) },
            this.props.label && React.createElement(InfoLabel, { className: "throttled-text-field-label", label: this.props.label, info: this.props.info }),
            React.createElement(TextField, tslib_1.__assign({}, props)),
            error && React.createElement(InputError, { className: "throttled-text-field-error", error: error })));
    };
    ThrottledTextField.prototype.componentWillUnmount = function () {
        _super.prototype.componentWillUnmount.call(this);
        this._disposeDelayedFunction();
    };
    ThrottledTextField.prototype.componentWillReceiveProps = function (nextProps, context) {
        _super.prototype.componentWillReceiveProps.call(this, nextProps, context);
        this._disposeDelayedFunction();
        if (nextProps.value !== this.state.internalValue) {
            this.setState({
                internalValue: nextProps.value
            });
        }
    };
    ThrottledTextField.prototype.initializeState = function () {
        this.state = {
            internalValue: this.props.value
        };
    };
    ThrottledTextField.prototype._refCallback = function (component) {
        this._component = component;
    };
    ThrottledTextField.prototype._onChange = function (value) {
        var _this = this;
        this._disposeDelayedFunction();
        var fireChange = function () {
            _this.setState({
                internalValue: value
            }, function () {
                if (_this.props.onChanged) {
                    _this.props.onChanged(value);
                }
            });
        };
        if (this.props.delay == null) {
            fireChange();
        }
        else {
            this._delayedFunction = delay(this, this.props.delay, function () {
                fireChange();
            });
        }
    };
    ThrottledTextField.prototype._disposeDelayedFunction = function () {
        if (this._delayedFunction) {
            this._delayedFunction.cancel();
            this._delayedFunction = null;
        }
    };
    ThrottledTextField.prototype._getDefaultError = function () {
        if (this.props.required && isNullOrEmpty(this.state.internalValue)) {
            return "A value is required";
        }
    };
    tslib_1.__decorate([
        autobind
    ], ThrottledTextField.prototype, "_refCallback", null);
    tslib_1.__decorate([
        autobind
    ], ThrottledTextField.prototype, "_onChange", null);
    return ThrottledTextField;
}(BaseFluxComponent));
export { ThrottledTextField };
//# sourceMappingURL=ThrottledTextField.js.map