import * as tslib_1 from "tslib";
import * as React from "react";
import { ClassificationNodeActions } from "../../../Flux/Actions/ClassificationNodeActions";
import { StoreFactory } from "../../../Flux/Stores/BaseStore";
import { ClassificationNodeKey, ClassificationNodeStore } from "../../../Flux/Stores/ClassificationNodeStore";
import { isNullOrEmpty } from "../../../Utilities/String";
import { BaseFluxComponent } from "../../Utilities/BaseFluxComponent";
import { TreeCombo } from "../../VssCombo/TreeCombo";
import { Spinner, SpinnerSize } from "OfficeFabric/Spinner";
import { autobind, css } from "OfficeFabric/Utilities";
import { TreeNode } from "VSS/Controls/TreeView";
var ClassificationPicker = (function (_super) {
    tslib_1.__extends(ClassificationPicker, _super);
    function ClassificationPicker() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._classificationNodeStore = StoreFactory.getInstance(ClassificationNodeStore);
        return _this;
    }
    ClassificationPicker.prototype.componentDidMount = function () {
        _super.prototype.componentDidMount.call(this);
        this._initializeNodes(this.props.keyType);
    };
    ClassificationPicker.prototype.componentWillReceiveProps = function (nextProps, context) {
        _super.prototype.componentWillReceiveProps.call(this, nextProps, context);
        if (nextProps.value !== this.props.value) {
            this.setState({
                value: nextProps.value
            });
        }
        if (nextProps.keyType !== this.props.keyType) {
            this._initializeNodes(nextProps.keyType);
        }
    };
    ClassificationPicker.prototype.render = function () {
        if (!this.state.treeNode) {
            return React.createElement(Spinner, { size: SpinnerSize.large });
        }
        var value = this.state.value;
        var error = this.props.error || this._getDefaultError();
        var props = tslib_1.__assign({}, this.props, { className: css("classification-picker", this.props.className), value: value, options: [this.state.treeNode], error: error, onChange: this._onChange });
        return React.createElement(TreeCombo, tslib_1.__assign({}, props));
    };
    ClassificationPicker.prototype.getStoresState = function () {
        return {
            treeNode: this._getTreeNode(this._classificationNodeStore.getItem(this.props.keyType), null, 1)
        };
    };
    ClassificationPicker.prototype.initializeState = function () {
        this.state = {
            value: this.props.value || ""
        };
    };
    ClassificationPicker.prototype.getStores = function () {
        return [this._classificationNodeStore];
    };
    ClassificationPicker.prototype._initializeNodes = function (keyType) {
        if (this._classificationNodeStore.isLoaded(keyType)) {
            this.setState({
                treeNode: this._getTreeNode(this._classificationNodeStore.getItem(keyType), null, 1)
            });
        }
        else if (keyType === ClassificationNodeKey.Area) {
            ClassificationNodeActions.initializeAreaPaths();
        }
        else {
            ClassificationNodeActions.initializeIterationPaths();
        }
    };
    ClassificationPicker.prototype._getTreeNode = function (node, uiNode, level) {
        if (!node) {
            return null;
        }
        var nodes = node.children;
        var newUINode;
        var nodeName = node.name;
        level = level || 1;
        if (uiNode) {
            newUINode = TreeNode.create(nodeName);
            uiNode.add(newUINode);
            uiNode = newUINode;
        }
        else {
            uiNode = TreeNode.create(nodeName);
        }
        uiNode.expanded = level < 2;
        if (nodes) {
            for (var _i = 0, nodes_1 = nodes; _i < nodes_1.length; _i++) {
                var n = nodes_1[_i];
                this._getTreeNode(n, uiNode, level + 1);
            }
        }
        return uiNode;
    };
    ClassificationPicker.prototype._onChange = function (value) {
        var _this = this;
        this.setState({ value: value }, function () {
            _this.props.onChange(value);
        });
    };
    ClassificationPicker.prototype._getDefaultError = function () {
        var nodePath = this.state.value;
        if (isNullOrEmpty(nodePath)) {
            return this.props.required ? "A value is required." : null;
        }
        else if (this.props.keyType === ClassificationNodeKey.Area) {
            return !this._classificationNodeStore.getAreaPathNode(nodePath) ? "This area path doesn't exist in the current project" : null;
        }
        else if (this.props.keyType === ClassificationNodeKey.Iteration) {
            return !this._classificationNodeStore.getIterationPathNode(nodePath) ? "This iteration path doesn't exist in the current project" : null;
        }
        return null;
    };
    tslib_1.__decorate([
        autobind
    ], ClassificationPicker.prototype, "_onChange", null);
    return ClassificationPicker;
}(BaseFluxComponent));
export { ClassificationPicker };
//# sourceMappingURL=ClassificationPicker.js.map