import * as tslib_1 from "tslib";
import * as React from "react";
import { WorkItemFieldActions } from "../../../Flux/Actions/WorkItemFieldActions";
import { WorkItemTypeActions } from "../../../Flux/Actions/WorkItemTypeActions";
import { StoreFactory } from "../../../Flux/Stores/BaseStore";
import { WorkItemFieldStore } from "../../../Flux/Stores/WorkItemFieldStore";
import { WorkItemTypeStore } from "../../../Flux/Stores/WorkItemTypeStore";
import { arrayEquals, contains } from "../../../Utilities/Array";
import { isNullOrWhiteSpace, stringEquals } from "../../../Utilities/String";
import { BaseFluxComponent } from "../../Utilities/BaseFluxComponent";
import { SimpleCombo } from "../../VssCombo/SimpleCombo";
import { Spinner, SpinnerSize } from "OfficeFabric/Spinner";
import { css } from "OfficeFabric/Utilities";
var WorkItemFieldPicker = (function (_super) {
    tslib_1.__extends(WorkItemFieldPicker, _super);
    function WorkItemFieldPicker() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._fieldStore = StoreFactory.getInstance(WorkItemFieldStore);
        _this._workItemTypeStore = StoreFactory.getInstance(WorkItemTypeStore);
        return _this;
    }
    WorkItemFieldPicker.prototype.componentDidMount = function () {
        _super.prototype.componentDidMount.call(this);
        var waitForStores = false;
        if (!this._fieldStore.isLoaded()) {
            WorkItemFieldActions.initializeWorkItemFields();
            waitForStores = true;
        }
        if (!isNullOrWhiteSpace(this.props.workItemType) && !this._workItemTypeStore.isLoaded()) {
            WorkItemTypeActions.initializeWorkItemTypes();
            waitForStores = true;
        }
        if (!waitForStores) {
            this.setState({
                allowedFields: this._getAllowedFields(this.props.allowedFieldTypes, this.props.excludeFields, this.props.workItemType)
            });
        }
    };
    WorkItemFieldPicker.prototype.componentWillReceiveProps = function (nextProps, context) {
        _super.prototype.componentWillReceiveProps.call(this, nextProps, context);
        if (!isNullOrWhiteSpace(nextProps.workItemType) && !this._workItemTypeStore.isLoaded()) {
            WorkItemTypeActions.initializeWorkItemTypes();
            return;
        }
        if (!arrayEquals(nextProps.allowedFieldTypes, this.props.allowedFieldTypes) || !arrayEquals(nextProps.excludeFields, this.props.excludeFields)) {
            this.setState({ allowedFields: this._getAllowedFields(nextProps.allowedFieldTypes, nextProps.excludeFields, nextProps.workItemType) });
        }
    };
    WorkItemFieldPicker.prototype.render = function () {
        if (!this.state.allowedFields) {
            return React.createElement(Spinner, { size: SpinnerSize.large });
        }
        var props = tslib_1.__assign({}, this.props, { className: css("work-item-field-picker", this.props.className), getItemText: function (field) { return field.name; }, options: this.state.allowedFields, limitedToAllowedOptions: true });
        return React.createElement(SimpleCombo, tslib_1.__assign({}, props));
    };
    WorkItemFieldPicker.prototype.getStores = function () {
        return [this._fieldStore, this._workItemTypeStore];
    };
    WorkItemFieldPicker.prototype.getStoresState = function () {
        return {
            allowedFields: this._getAllowedFields(this.props.allowedFieldTypes, this.props.excludeFields, this.props.workItemType)
        };
    };
    WorkItemFieldPicker.prototype._getAllowedFields = function (allowedFieldTypes, excludeFields, workItemType) {
        var _this = this;
        if (!this._fieldStore.isLoaded() || (!isNullOrWhiteSpace(workItemType) && !this._workItemTypeStore.isLoaded())) {
            return null;
        }
        var allFields = this._fieldStore.getAll();
        return allFields.filter(function (f) {
            var witFields;
            if (!isNullOrWhiteSpace(workItemType) && _this._workItemTypeStore.itemExists(workItemType)) {
                witFields = _this._workItemTypeStore.getItem(workItemType).fields.map(function (wf) { return wf.referenceName; });
            }
            return (!allowedFieldTypes || allowedFieldTypes.indexOf(f.type) !== -1)
                && (!excludeFields || !contains(excludeFields, f.referenceName, function (a, b) { return stringEquals(a, b, true); }))
                && (!witFields || contains(witFields, f.referenceName, function (s1, s2) { return stringEquals(s1, s2, true); }));
        });
    };
    return WorkItemFieldPicker;
}(BaseFluxComponent));
export { WorkItemFieldPicker };
//# sourceMappingURL=WorkItemFieldPicker.js.map