import * as tslib_1 from "tslib";
import * as React from "react";
import { WorkItemTypeFieldAllowedValuesActions } from "../../../Flux/Actions/WorkItemTypeFieldAllowedValuesActions";
import { StoreFactory } from "../../../Flux/Stores/BaseStore";
import { ClassificationNodeKey } from "../../../Flux/Stores/ClassificationNodeStore";
import { WorkItemTypeFieldAllowedValuesStore } from "../../../Flux/Stores/WorkItemTypeFieldAllowedValuesStore";
import { isNullOrWhiteSpace, stringEquals } from "../../../Utilities/String";
import { RichEditor } from "../../RichEditor";
import { BaseFluxComponent } from "../../Utilities/BaseFluxComponent";
import { ThrottledTextField } from "../../Utilities/ThrottledTextField";
import { DatePickerCombo } from "../../VssCombo/DatePickerCombo";
import { SimpleCombo } from "../../VssCombo/SimpleCombo";
import { WorkItemTagPicker } from "../../VSTS/WorkItemTagPicker";
import { ClassificationPicker } from "../ClassificationPicker";
import { Checkbox } from "OfficeFabric/Checkbox";
import { autobind, css } from "OfficeFabric/Utilities";
import { FieldType } from "TFS/WorkItemTracking/Contracts";
var WorkItemFieldValuePicker = (function (_super) {
    tslib_1.__extends(WorkItemFieldValuePicker, _super);
    function WorkItemFieldValuePicker() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._fieldAllowedValuesStore = StoreFactory.getInstance(WorkItemTypeFieldAllowedValuesStore);
        return _this;
    }
    WorkItemFieldValuePicker.prototype.componentDidMount = function () {
        _super.prototype.componentDidMount.call(this);
        var _a = this.props, field = _a.field, workItemType = _a.workItemType;
        if (this._fieldSupportsAllowedValues(field)) {
            var allowedValues = this._fieldAllowedValuesStore.getAllowedValues(workItemType, field.referenceName);
            if (allowedValues == null) {
                WorkItemTypeFieldAllowedValuesActions.initializeAllowedValues(workItemType, field.referenceName);
            }
            else {
                this.setState({ allowedValues: allowedValues });
            }
        }
    };
    WorkItemFieldValuePicker.prototype.componentWillReceiveProps = function (nextProps, context) {
        _super.prototype.componentWillReceiveProps.call(this, nextProps, context);
        var field = nextProps.field, workItemType = nextProps.workItemType;
        var oldField = this.props.field;
        var oldWorkItemType = this.props.workItemType;
        if (!stringEquals(field.referenceName, oldField.referenceName, true) || !stringEquals(oldWorkItemType, workItemType, true)) {
            if (this._fieldSupportsAllowedValues(field)) {
                var allowedValues = this._fieldAllowedValuesStore.getAllowedValues(workItemType, field.referenceName);
                this.setState({ allowedValues: allowedValues });
                if (allowedValues == null) {
                    WorkItemTypeFieldAllowedValuesActions.initializeAllowedValues(workItemType, field.referenceName);
                }
            }
        }
    };
    WorkItemFieldValuePicker.prototype.render = function () {
        var _a = this.props, field = _a.field, value = _a.value, delay = _a.delay, label = _a.label, disabled = _a.disabled, info = _a.info, required = _a.required, error = _a.error;
        var className = css("field-value-picker", this.props.className);
        if (!field || (this._fieldSupportsAllowedValues(field) && this.state.allowedValues == null)) {
            return (React.createElement(ThrottledTextField, { className: className, value: "", label: label, info: info, disabled: true }));
        }
        if (field.referenceName === "System.Tags") {
            return (React.createElement(WorkItemTagPicker, { label: label, info: info, required: required, error: error, disabled: disabled, selectedTags: isNullOrWhiteSpace(value) ? [] : value.split(";"), onChange: this._onTagsChange }));
        }
        switch (field.type) {
            case FieldType.Boolean:
                var checked = (value === 1 || stringEquals(value, "true", true) || value === true) ? true : false;
                return (React.createElement(Checkbox, { className: className, checked: checked, onChange: this._onCheckboxChange, disabled: disabled }));
            case FieldType.PlainText:
                return (React.createElement(ThrottledTextField, { className: className, value: value, multiline: true, resizable: false, label: label, info: info, delay: delay, required: required, errorMessage: error, disabled: disabled, onChanged: this._onFieldValueChange }));
            case FieldType.History:
            case FieldType.Html:
                var richEditorOptions = {
                    svgPath: VSS.getExtensionContext().baseUri + "/3rdParty/icons.png",
                    btns: [
                        ["bold", "italic"],
                        ["superscript", "subscript"],
                        ["unorderedList", "orderedList"],
                        ["link"],
                        ["removeformat"],
                        ["fullscreen"]
                    ]
                };
                return (React.createElement(RichEditor, { className: className, value: value, label: label, info: info, disabled: disabled, delay: delay, required: required, error: error, editorOptions: richEditorOptions, onChange: this._onFieldValueChange }));
            case FieldType.TreePath:
                return (React.createElement(ClassificationPicker, { value: value, className: className, label: label, info: info, delay: delay, required: required, disabled: disabled, error: error, onChange: this._onFieldValueChange, keyType: field.referenceName === "System.AreaPath" ? ClassificationNodeKey.Area : ClassificationNodeKey.Iteration }));
            case FieldType.DateTime:
                return (React.createElement(DatePickerCombo, { value: value, className: className, label: label, info: info, delay: delay, required: required, disabled: disabled, error: error, onChange: this._onFieldValueChange }));
            default:
                return (React.createElement(SimpleCombo, { options: this.state.allowedValues, selectedValue: value, className: className, label: label, info: info, delay: delay, required: required, disabled: disabled, error: error, onChange: this._onFieldValueChange }));
        }
    };
    WorkItemFieldValuePicker.prototype.initializeState = function () {
        this.state = {
            allowedValues: null
        };
    };
    WorkItemFieldValuePicker.prototype.getStoresState = function () {
        return {
            allowedValues: this._fieldAllowedValuesStore.getAllowedValues(this.props.workItemType, this.props.field.referenceName)
        };
    };
    WorkItemFieldValuePicker.prototype.getStores = function () {
        return [this._fieldAllowedValuesStore];
    };
    WorkItemFieldValuePicker.prototype._fieldSupportsAllowedValues = function (field) {
        return WorkItemFieldValuePicker.FieldTypesSupportingAllowedValues.indexOf(field.type) !== -1;
    };
    WorkItemFieldValuePicker.prototype._onCheckboxChange = function (_ev, checked) {
        return this._onFieldValueChange(checked);
    };
    WorkItemFieldValuePicker.prototype._onFieldValueChange = function (value) {
        this.props.onChange(value);
    };
    WorkItemFieldValuePicker.prototype._onTagsChange = function (tags) {
        this.props.onChange(tags.join(";"));
    };
    WorkItemFieldValuePicker.FieldTypesSupportingAllowedValues = [
        FieldType.String,
        FieldType.Integer,
        FieldType.Double,
        FieldType.PicklistDouble,
        FieldType.PicklistInteger,
        FieldType.PicklistString
    ];
    tslib_1.__decorate([
        autobind
    ], WorkItemFieldValuePicker.prototype, "_onCheckboxChange", null);
    tslib_1.__decorate([
        autobind
    ], WorkItemFieldValuePicker.prototype, "_onFieldValueChange", null);
    tslib_1.__decorate([
        autobind
    ], WorkItemFieldValuePicker.prototype, "_onTagsChange", null);
    return WorkItemFieldValuePicker;
}(BaseFluxComponent));
export { WorkItemFieldValuePicker };
//# sourceMappingURL=WorkItemFieldValuePicker.js.map