import * as tslib_1 from "tslib";
import "./WorkItemStateView.css";
import * as React from "react";
import { WorkItemStateItemActions } from "../../../Flux/Actions/WorkItemStateItemActions";
import { StoreFactory } from "../../../Flux/Stores/BaseStore";
import { WorkItemStateItemStore } from "../../../Flux/Stores/WorkItemStateItemStore";
import { first } from "../../../Utilities/Array";
import { stringEquals } from "../../../Utilities/String";
import { BaseFluxComponent } from "../../Utilities/BaseFluxComponent";
import { Label } from "OfficeFabric/Label";
import { css } from "OfficeFabric/Utilities";
var WorkItemStateView = (function (_super) {
    tslib_1.__extends(WorkItemStateView, _super);
    function WorkItemStateView() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._workItemStateItemStore = StoreFactory.getInstance(WorkItemStateItemStore);
        return _this;
    }
    WorkItemStateView.prototype.componentDidMount = function () {
        var _this = this;
        _super.prototype.componentDidMount.call(this);
        if (this._workItemStateItemStore.isLoaded(this.props.workItemType)) {
            var workItemTypeStates = this._workItemStateItemStore.getItem(this.props.workItemType);
            this.setState({
                workItemTypeState: first(workItemTypeStates, function (s) { return stringEquals(s.name, _this.props.state, true); })
            });
        }
        else {
            WorkItemStateItemActions.initializeWorkItemStates(this.props.workItemType);
        }
    };
    WorkItemStateView.prototype.componentWillReceiveProps = function (nextProps, context) {
        _super.prototype.componentWillReceiveProps.call(this, nextProps, context);
        if (!stringEquals(nextProps.state, this.props.state, true) || !stringEquals(nextProps.workItemType, this.props.workItemType, true)) {
            if (this._workItemStateItemStore.isLoaded(nextProps.workItemType)) {
                var workItemTypeStates = this._workItemStateItemStore.getItem(nextProps.workItemType);
                this.setState({
                    workItemTypeState: first(workItemTypeStates, function (s) { return stringEquals(s.name, nextProps.state, true); })
                });
            }
            else {
                WorkItemStateItemActions.initializeWorkItemStates(nextProps.workItemType);
            }
        }
    };
    WorkItemStateView.prototype.render = function () {
        var stateColor;
        if (this.state.workItemTypeState && this.state.workItemTypeState.color) {
            stateColor = "#" + this.state.workItemTypeState.color.substring(this.state.workItemTypeState.color.length - 6);
        }
        else {
            stateColor = "#000000";
        }
        return (React.createElement("div", { className: css("work-item-state-view", this.props.className) },
            React.createElement("span", { className: "work-item-type-state-color", style: {
                    backgroundColor: stateColor,
                    borderColor: stateColor
                } }),
            React.createElement(Label, { className: "state-name" }, this.props.state)));
    };
    WorkItemStateView.prototype.getStoresState = function () {
        var _this = this;
        var workItemTypeStates = this._workItemStateItemStore.getItem(this.props.workItemType);
        return {
            workItemTypeState: workItemTypeStates ? first(workItemTypeStates, function (s) { return stringEquals(s.name, _this.props.state, true); }) : null
        };
    };
    WorkItemStateView.prototype.initializeState = function () {
        this.state = { workItemTypeState: null };
    };
    WorkItemStateView.prototype.getStores = function () {
        return [this._workItemStateItemStore];
    };
    return WorkItemStateView;
}(BaseFluxComponent));
export { WorkItemStateView };
//# sourceMappingURL=WorkItemStateView.js.map