import * as tslib_1 from "tslib";
import "./WorkItemTagPicker.css";
import * as React from "react";
import { WorkItemTagActions } from "../../../Flux/Actions/WorkItemTagActions";
import { StoreFactory } from "../../../Flux/Stores/BaseStore";
import { WorkItemTagStore } from "../../../Flux/Stores/WorkItemTagStore";
import { findIndex } from "../../../Utilities/Array";
import { isNullOrWhiteSpace, stringEquals } from "../../../Utilities/String";
import { InfoLabel } from "../../InfoLabel";
import { InputError } from "../../InputError";
import { BaseFluxComponent } from "../../Utilities/BaseFluxComponent";
import { TagPicker } from "OfficeFabric/components/pickers/TagPicker/TagPicker";
import { Spinner, SpinnerSize } from "OfficeFabric/Spinner";
import { autobind, css } from "OfficeFabric/Utilities";
var WorkItemTagPicker = (function (_super) {
    tslib_1.__extends(WorkItemTagPicker, _super);
    function WorkItemTagPicker() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._workItemTagStore = StoreFactory.getInstance(WorkItemTagStore);
        return _this;
    }
    WorkItemTagPicker.prototype.componentDidMount = function () {
        _super.prototype.componentDidMount.call(this);
        if (this._workItemTagStore.isLoaded()) {
            this.setState({
                allTags: this._workItemTagStore.getAll()
            });
        }
        else {
            WorkItemTagActions.initializeTags();
        }
    };
    WorkItemTagPicker.prototype.render = function () {
        var _this = this;
        if (!this.state.allTags) {
            return React.createElement(Spinner, { size: SpinnerSize.large });
        }
        var _a = this.props, label = _a.label, disabled = _a.disabled, info = _a.info, _b = _a.selectedTags, selectedTags = _b === void 0 ? [] : _b, className = _a.className;
        var error = this.props.error || this._getDefaultError();
        return (React.createElement("div", { className: css("work-item-tag-picker", className) },
            label && React.createElement(InfoLabel, { className: "work-item-tag-picker-label", label: label, info: info }),
            React.createElement(TagPicker, { disabled: disabled, defaultSelectedItems: (selectedTags).map(function (t) { return _this._getTag(t); }), onResolveSuggestions: this._onTagFilterChanged, getTextFromItem: this._getTagText, onChange: this._onChange, inputProps: {
                    style: {
                        height: "26px"
                    }
                }, pickerSuggestionsProps: {
                    suggestionsHeaderText: "Suggested Tags",
                    noResultsFoundText: "No tags Found"
                } }),
            error && React.createElement(InputError, { className: "work-item-tag-picker-error", error: error })));
    };
    WorkItemTagPicker.prototype.getStoresState = function () {
        return {
            allTags: this._workItemTagStore.getAll()
        };
    };
    WorkItemTagPicker.prototype.getStores = function () {
        return [this._workItemTagStore];
    };
    WorkItemTagPicker.prototype.initializeState = function () {
        this.state = {
            selectedTags: this.props.selectedTags
        };
    };
    WorkItemTagPicker.prototype._getDefaultError = function () {
        if (!this.state.selectedTags || this.state.selectedTags.length === 0) {
            return this.props.required ? "A value is required." : null;
        }
        return null;
    };
    WorkItemTagPicker.prototype._onChange = function (items) {
        var _this = this;
        var selectedTags = items.map(function (i) { return i.name; });
        this.setState({
            selectedTags: selectedTags
        }, function () {
            if (_this.props.onChange) {
                _this.props.onChange(selectedTags);
            }
        });
    };
    WorkItemTagPicker.prototype._getTag = function (tag) {
        return {
            key: tag,
            name: tag
        };
    };
    WorkItemTagPicker.prototype._getTagText = function (tag) {
        return tag.name;
    };
    WorkItemTagPicker.prototype._onTagFilterChanged = function (filterText, tagList) {
        if (isNullOrWhiteSpace(filterText)) {
            return [];
        }
        var filteredTags = this.state.allTags
            .filter(function (tag) { return tag.name.toLowerCase().indexOf(filterText.toLowerCase()) === 0 && findIndex(tagList, function (t) { return stringEquals(t.key, tag.name, true); }) === -1; })
            .map(function (tag) {
            return { key: tag.name, name: tag.name };
        });
        if (findIndex(filteredTags, function (t) { return stringEquals(t.key, filterText, true); }) === -1) {
            filteredTags.unshift({ key: filterText, name: filterText });
        }
        return filteredTags;
    };
    tslib_1.__decorate([
        autobind
    ], WorkItemTagPicker.prototype, "_onChange", null);
    tslib_1.__decorate([
        autobind
    ], WorkItemTagPicker.prototype, "_getTag", null);
    tslib_1.__decorate([
        autobind
    ], WorkItemTagPicker.prototype, "_getTagText", null);
    tslib_1.__decorate([
        autobind
    ], WorkItemTagPicker.prototype, "_onTagFilterChanged", null);
    return WorkItemTagPicker;
}(BaseFluxComponent));
export { WorkItemTagPicker };
//# sourceMappingURL=WorkItemTagPicker.js.map