import * as tslib_1 from "tslib";
import "./VssCombo.css";
import * as React from "react";
import { delay } from "../../Utilities/Core";
import { isNullOrEmpty } from "../../Utilities/String";
import { InfoLabel } from "../InfoLabel";
import { InputError } from "../InputError";
import { BaseFluxComponent } from "../Utilities/BaseFluxComponent";
import { autobind, css } from "OfficeFabric/Utilities";
import { Control } from "VSS/Controls";
import { Combo } from "VSS/Controls/Combos";
var DatePickerCombo = (function (_super) {
    tslib_1.__extends(DatePickerCombo, _super);
    function DatePickerCombo() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._containerRefCallback = function (container) { _this._container = container; };
        return _this;
    }
    DatePickerCombo.prototype.focus = function () {
        if (this._control) {
            this._control.focus();
        }
    };
    DatePickerCombo.prototype.render = function () {
        var error = this.props.error || this._getDefaultError();
        return (React.createElement("div", { className: css("vss-combobox", "datetime-combo", this.props.className) },
            this.props.label && React.createElement(InfoLabel, { className: "vss-combo-label", label: this.props.label, info: this.props.info }),
            React.createElement("div", { ref: this._containerRefCallback }),
            error && React.createElement(InputError, { className: "vss-combo-error", error: error })));
    };
    DatePickerCombo.prototype.componentDidMount = function () {
        _super.prototype.componentDidMount.call(this);
        var comboOptions = {
            type: "date-time",
            value: this.state.value,
            allowEdit: true,
            enabled: !this.props.disabled,
            change: this._onChange
        };
        this._control = Control.create(Combo, $(this._container), comboOptions);
    };
    DatePickerCombo.prototype.componentWillUnmount = function () {
        _super.prototype.componentWillUnmount.call(this);
        this._dispose();
    };
    DatePickerCombo.prototype.componentWillReceiveProps = function (nextProps, context) {
        _super.prototype.componentWillReceiveProps.call(this, nextProps, context);
        this._disposeDelayedFunction();
        if (nextProps.value !== this.state.value) {
            this._control.setInputText(nextProps.value);
            this.setState({
                value: nextProps.value
            });
        }
        if (nextProps.disabled !== this.props.disabled) {
            this._control.setEnabled(!nextProps.disabled);
        }
    };
    DatePickerCombo.prototype.initializeState = function () {
        this.state = {
            value: this.props.value || ""
        };
    };
    DatePickerCombo.prototype._dispose = function () {
        if (this._control) {
            this._control.dispose();
            this._control = null;
        }
        this._disposeDelayedFunction();
    };
    DatePickerCombo.prototype._getDefaultError = function () {
        if (this.props.required && isNullOrEmpty(this.state.value)) {
            return "A value is required";
        }
    };
    DatePickerCombo.prototype._onChange = function () {
        var _this = this;
        this._disposeDelayedFunction();
        var fireChange = function () {
            var value = _this._control.getText();
            _this.setState({
                value: value
            }, function () {
                _this.props.onChange(value);
            });
        };
        if (this.props.delay == null) {
            fireChange();
        }
        else {
            this._delayedFunction = delay(this, this.props.delay, function () {
                fireChange();
            });
        }
    };
    DatePickerCombo.prototype._disposeDelayedFunction = function () {
        if (this._delayedFunction) {
            this._delayedFunction.cancel();
            this._delayedFunction = null;
        }
    };
    tslib_1.__decorate([
        autobind
    ], DatePickerCombo.prototype, "_onChange", null);
    return DatePickerCombo;
}(BaseFluxComponent));
export { DatePickerCombo };
//# sourceMappingURL=DatePickerCombo.js.map