import * as tslib_1 from "tslib";
import "./VssCombo.css";
import * as React from "react";
import { delay } from "../../Utilities/Core";
import { isNullOrEmpty } from "../../Utilities/String";
import { InfoLabel } from "../InfoLabel";
import { InputError } from "../InputError";
import { BaseFluxComponent } from "../Utilities/BaseFluxComponent";
import { autobind, css } from "OfficeFabric/Utilities";
import { Control } from "VSS/Controls";
import { Combo } from "VSS/Controls/Combos";
var SimpleCombo = (function (_super) {
    tslib_1.__extends(SimpleCombo, _super);
    function SimpleCombo() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._containerRefCallback = function (container) { _this._container = container; };
        return _this;
    }
    SimpleCombo.prototype.focus = function () {
        if (this._control) {
            this._control.focus();
        }
    };
    SimpleCombo.prototype.render = function () {
        var error = this.props.error || this._getDefaultError();
        return (React.createElement("div", { className: css("vss-combobox", "simple-combo", this.props.className) },
            this.props.label && React.createElement(InfoLabel, { className: "vss-combo-label", label: this.props.label, info: this.props.info }),
            React.createElement("div", { ref: this._containerRefCallback }),
            error && React.createElement(InputError, { className: "vss-combo-error", error: error })));
    };
    SimpleCombo.prototype.componentDidMount = function () {
        var _this = this;
        _super.prototype.componentDidMount.call(this);
        var _a = this.props, _b = _a.options, options = _b === void 0 ? [] : _b, getItemText = _a.getItemText, selectedOption = _a.selectedOption, selectedValue = _a.selectedValue, disabled = _a.disabled;
        this._buildOptionsMap(options, getItemText);
        var comboOptions = {
            type: "list",
            mode: "drop",
            value: this._getTextValue(selectedOption, selectedValue, getItemText),
            allowEdit: true,
            source: options.map(function (o) { return _this._getTextValue(o, null, getItemText); }),
            enabled: !disabled,
            maxAutoExpandDropWidth: 400,
            change: this._onChange
        };
        this._control = Control.create(Combo, $(this._container), comboOptions);
    };
    SimpleCombo.prototype.componentWillUnmount = function () {
        _super.prototype.componentWillUnmount.call(this);
        this._dispose();
    };
    SimpleCombo.prototype.componentWillReceiveProps = function (nextProps, context) {
        _super.prototype.componentWillReceiveProps.call(this, nextProps, context);
        this._disposeDelayedFunction();
        var nextValue = this._getTextValue(nextProps.selectedOption, nextProps.selectedValue, nextProps.getItemText);
        var currentValue = this._getTextValue(this.state.selectedOption, this.state.selectedValue, this.props.getItemText);
        if (nextValue !== currentValue) {
            this._control.setInputText(nextValue);
            this.setState({
                selectedOption: nextProps.selectedOption,
                selectedValue: nextProps.selectedValue
            });
        }
        if (nextProps.disabled !== this.props.disabled) {
            this._control.setEnabled(!nextProps.disabled);
        }
    };
    SimpleCombo.prototype.initializeState = function () {
        this.state = {
            selectedOption: this.props.selectedOption,
            selectedValue: this.props.selectedValue || ""
        };
    };
    SimpleCombo.prototype._buildOptionsMap = function (options, getItemText) {
        this._nameToOptionMap = {};
        for (var _i = 0, options_1 = options; _i < options_1.length; _i++) {
            var option = options_1[_i];
            var value = this._getTextValue(option, null, getItemText);
            this._nameToOptionMap[value.toLowerCase()] = option;
        }
    };
    SimpleCombo.prototype._dispose = function () {
        if (this._control) {
            this._control.dispose();
            this._control = null;
        }
        this._disposeDelayedFunction();
    };
    SimpleCombo.prototype._getTextValue = function (option, value, getItemText) {
        var v = value;
        if (option) {
            v = getItemText ? getItemText(option) : "" + option;
        }
        return v || "";
    };
    SimpleCombo.prototype._getDefaultError = function () {
        var _a = this.props, required = _a.required, limitedToAllowedOptions = _a.limitedToAllowedOptions;
        var _b = this.state, selectedOption = _b.selectedOption, selectedValue = _b.selectedValue;
        if (!selectedOption && isNullOrEmpty(selectedValue)) {
            return required ? "A value is required." : null;
        }
        if (limitedToAllowedOptions && !selectedOption && !this._isSelectedValueValid(selectedValue)) {
            return "This value is not in the list of allowed values.";
        }
        return null;
    };
    SimpleCombo.prototype._isSelectedValueValid = function (value) {
        return (this._nameToOptionMap && this._nameToOptionMap[(value || "").toLowerCase()]) ? true : false;
    };
    SimpleCombo.prototype._onChange = function () {
        var _this = this;
        this._disposeDelayedFunction();
        var fireChange = function () {
            var value = _this._control.getText() || "";
            var option = (_this._nameToOptionMap && _this._nameToOptionMap[value.toLowerCase()]) || null;
            if (option) {
                value = null;
            }
            _this.setState({
                selectedOption: option,
                selectedValue: value
            }, function () {
                _this.props.onChange(option, value);
            });
        };
        if (this.props.delay == null) {
            fireChange();
        }
        else {
            this._delayedFunction = delay(this, this.props.delay, function () {
                fireChange();
            });
        }
    };
    SimpleCombo.prototype._disposeDelayedFunction = function () {
        if (this._delayedFunction) {
            this._delayedFunction.cancel();
            this._delayedFunction = null;
        }
    };
    tslib_1.__decorate([
        autobind
    ], SimpleCombo.prototype, "_onChange", null);
    return SimpleCombo;
}(BaseFluxComponent));
export { SimpleCombo };
//# sourceMappingURL=SimpleCombo.js.map