import * as tslib_1 from "tslib";
import { ClassificationNodeActionsHub } from "../Actions/ActionsHub";
import { BaseStore } from "./BaseStore";
export var ClassificationNodeKey;
(function (ClassificationNodeKey) {
    ClassificationNodeKey["Area"] = "Area";
    ClassificationNodeKey["Iteration"] = "Iteration";
})(ClassificationNodeKey || (ClassificationNodeKey = {}));
var ClassificationNodeStore = (function (_super) {
    tslib_1.__extends(ClassificationNodeStore, _super);
    function ClassificationNodeStore() {
        var _this = _super.call(this) || this;
        _this.items = {};
        _this._areaPathIdMap = {};
        _this._areaPathMap = {};
        _this._iterationPathIdMap = {};
        _this._iterationPathMap = {};
        return _this;
    }
    ClassificationNodeStore.prototype.getItem = function (nodeKey) {
        return nodeKey === ClassificationNodeKey.Area ? this.items.areaPathRoot : this.items.iterationPathRoot;
    };
    ClassificationNodeStore.prototype.getAreaPathNode = function (nodeIdOrPath) {
        var key = (nodeIdOrPath || "").toLowerCase();
        return this._areaPathIdMap[key] || this._areaPathMap[key];
    };
    ClassificationNodeStore.prototype.getIterationPathNode = function (nodeIdOrPath) {
        var key = (nodeIdOrPath || "").toLowerCase();
        return this._iterationPathIdMap[key] || this._iterationPathMap[key];
    };
    ClassificationNodeStore.prototype.getKey = function () {
        return "ClassificationNodeStore";
    };
    ClassificationNodeStore.prototype.initializeActionListeners = function () {
        var _this = this;
        ClassificationNodeActionsHub.InitializeAreaPaths.addListener(function (rootNode) {
            if (rootNode) {
                _this.items.areaPathRoot = rootNode;
                _this._populateNodeData(rootNode, null, ClassificationNodeKey.Area);
            }
            _this.emitChanged();
        });
        ClassificationNodeActionsHub.InitializeIterationPaths.addListener(function (rootNode) {
            if (rootNode) {
                _this.items.iterationPathRoot = rootNode;
                _this._populateNodeData(rootNode, null, ClassificationNodeKey.Iteration);
            }
            _this.emitChanged();
        });
    };
    ClassificationNodeStore.prototype.convertItemKeyToString = function (key) {
        return key;
    };
    ClassificationNodeStore.prototype._populateNodeData = function (node, parentNodeName, nodeType) {
        var nodeName = parentNodeName ? parentNodeName + "\\" + node.name : node.name;
        if (nodeType === ClassificationNodeKey.Area) {
            this._areaPathMap[nodeName.toLowerCase()] = node;
            this._areaPathIdMap[node.id.toString()] = node;
        }
        else {
            this._iterationPathMap[nodeName.toLowerCase()] = node;
            this._iterationPathIdMap[node.id.toString()] = node;
        }
        if (node.children) {
            for (var _i = 0, _a = node.children; _i < _a.length; _i++) {
                var child = _a[_i];
                this._populateNodeData(child, nodeName, nodeType);
            }
        }
    };
    return ClassificationNodeStore;
}(BaseStore));
export { ClassificationNodeStore };
//# sourceMappingURL=ClassificationNodeStore.js.map