export function first(array, predicate) {
    if (!array || array.length === 0) {
        return null;
    }
    if (predicate == null) {
        return array[0];
    }
    var items = array.filter(predicate);
    return (items && items.length > 0) ? items[0] : null;
}
export function findIndex(array, predicate) {
    for (var i = 0; i < array.length; i++) {
        if (predicate(array[i])) {
            return i;
        }
    }
    return -1;
}
export function union(arrayA, arrayB, comparer) {
    var result;
    if (!arrayB || arrayB.length === 0) {
        return arrayA;
    }
    result = arrayA.concat(arrayB);
    uniqueSort(result, comparer);
    return result;
}
export function uniqueSort(array, comparer) {
    comparer = comparer || defaultComparer;
    array.sort(comparer);
    var l = array.length;
    for (var i = 1; i < l; i++) {
        if (comparer(array[i], array[i - 1]) === 0) {
            array.splice(i--, 1);
            l--;
        }
    }
    return array;
}
export function unique(array, comparer) {
    var result = array.slice(0);
    uniqueSort(result, comparer);
    return result;
}
export function removeWhere(array, predicate, count, startAt) {
    if (startAt === void 0) { startAt = 0; }
    var indexesToRemove = [];
    for (var i = startAt; i < array.length; ++i) {
        if (predicate(array[i])) {
            indexesToRemove.push(i);
            if (indexesToRemove.length === count) {
                break;
            }
        }
    }
    removeAllIndexes(array, indexesToRemove);
}
export function removeAtIndex(array, index) {
    return removeAllIndexes(array, [index]);
}
export function subtract(arrayA, arrayB, comparer) {
    var result = [];
    if (!arrayA || arrayA.length === 0 || !arrayB || arrayB.length === 0) {
        return arrayA;
    }
    for (var _i = 0, arrayA_1 = arrayA; _i < arrayA_1.length; _i++) {
        var val = arrayA_1[_i];
        if (!contains(arrayB, val, comparer)) {
            result.push(val);
        }
    }
    return result;
}
export function removeAllIndexes(array, indexes) {
    var result = true;
    var sortedIndexes = indexes.slice();
    sortedIndexes.sort(function (a, b) { return Number(a) - Number(b); });
    for (var i = sortedIndexes.length - 1; i >= 0; --i) {
        var index = sortedIndexes[i];
        if (index >= array.length || index < 0) {
            result = false;
            continue;
        }
        array.splice(index, 1);
    }
    return result;
}
export function contains(array, value, comparer) {
    if (value == null) {
        return false;
    }
    for (var _i = 0, array_1 = array; _i < array_1.length; _i++) {
        var item = array_1[_i];
        if (comparer(item, value)) {
            return true;
        }
    }
    return false;
}
export function arrayEquals(source, target, comparer, sorted) {
    if (sorted === void 0) { sorted = false; }
    if (!source && !target) {
        return true;
    }
    if ((!source && target) || (source && !target)) {
        return false;
    }
    if (source.length !== target.length) {
        return false;
    }
    if (!comparer) {
        comparer = defaultComparison;
    }
    if (!sorted) {
        for (var _i = 0, source_1 = source; _i < source_1.length; _i++) {
            var s = source_1[_i];
            if (!contains(target, s, comparer)) {
                return false;
            }
        }
    }
    else {
        for (var i = 0; i < source.length; i++) {
            if (!comparer(source[i], target[i])) {
                return false;
            }
        }
    }
    return true;
}
function defaultComparer(a, b) {
    if (a === b) {
        return 0;
    }
    else if (a > b) {
        return 1;
    }
    else {
        return -1;
    }
}
function defaultComparison(a, b) {
    return a === b;
}
//# sourceMappingURL=Array.js.map