export function copyToClipboard(data, options) {
    var dataCopied = false;
    if (data && typeof data === "string") {
        if (options && options.copyAsHtml) {
            if (supportsNativeHtmlCopy()) {
                try {
                    dataCopied = nativeCopy(data, true);
                }
                catch (_a) {
                }
            }
        }
        else {
            if (supportsNativeCopy()) {
                try {
                    dataCopied = nativeCopy(data, false);
                }
                catch (_b) {
                }
            }
        }
    }
    return dataCopied;
}
export function supportsNativeCopy() {
    return document.queryCommandSupported("copy") || window.clipboardData !== undefined;
}
export function supportsNativeHtmlCopy() {
    return document.body.createTextRange !== undefined
        || (document.queryCommandSupported("copy") && document.createRange !== undefined);
}
function nativeCopy(data, copyAsHtml) {
    var success = false;
    if (!copyAsHtml && window.clipboardData !== undefined) {
        window.clipboardData.setData("text", data);
        success = true;
    }
    else {
        var range = void 0;
        var sel = void 0;
        var $copyContent = $("<div/>");
        try {
            $copyContent.css("background-color", "white");
            if (copyAsHtml) {
                $copyContent.append(data);
            }
            else {
                $copyContent.css("white-space", "pre");
                $copyContent.text(data);
            }
            if (document.body.createTextRange) {
                $copyContent.prependTo($("body"));
                range = document.body.createTextRange();
                range.moveToElementText($copyContent[0]);
                range.select();
                success = range.execCommand("copy");
            }
            else if (document.createRange && window.getSelection) {
                $copyContent.appendTo($("body"));
                range = document.createRange();
                sel = window.getSelection();
                sel.removeAllRanges();
                range.selectNodeContents($copyContent[0]);
                sel.addRange(range);
                success = document.execCommand("copy");
            }
        }
        finally {
            $copyContent.remove();
        }
    }
    return success;
}
//# sourceMappingURL=Clipboard.js.map