import * as tslib_1 from "tslib";
export function delegate(instance, method, data) {
    return function () {
        if (data == null) {
            return method.apply(instance, arguments);
        }
        else {
            var args = Array.prototype.slice.call(arguments, 0);
            if (data instanceof Array) {
                args = args.concat(data);
            }
            else {
                args.push(data);
            }
            return method.apply(instance, args);
        }
    };
}
var DelayedFunction = (function () {
    function DelayedFunction(instance, ms, method, data) {
        this._interval = ms;
        this._func = delegate(instance, method, data);
    }
    DelayedFunction.prototype.dispose = function () {
        this.cancel();
        this._func = null;
    };
    DelayedFunction.prototype.start = function () {
        var _this = this;
        if (!this._timeoutHandle) {
            this._timeoutHandle = window.setTimeout(function () {
                delete _this._timeoutHandle;
                try {
                    _this._invoke.call(_this);
                }
                catch (_a) {
                }
            }, this._interval);
        }
    };
    DelayedFunction.prototype.reset = function () {
        this.cancel();
        this.start();
    };
    DelayedFunction.prototype.cancel = function () {
        if (this._timeoutHandle) {
            window.clearTimeout(this._timeoutHandle);
            delete this._timeoutHandle;
        }
    };
    DelayedFunction.prototype.invokeNow = function () {
        this.cancel();
        this._invoke();
    };
    DelayedFunction.prototype.isPending = function () {
        return this._timeoutHandle ? true : false;
    };
    DelayedFunction.prototype._invoke = function () {
        this._func();
    };
    return DelayedFunction;
}());
export { DelayedFunction };
export function delay(instance, ms, method, data) {
    var delayedFunc = new DelayedFunction(instance, ms, method, data);
    delayedFunc.start();
    return delayedFunc;
}
export function throttledDelegate(instance, ms, method, data) {
    var delayedFunc = new DelayedFunction(instance, ms, method, data);
    return delegate(delayedFunc, function () {
        delayedFunc.reset();
    });
}
export function confirmAction(condition, msg) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var dialogService, e_1;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    if (!condition) return [3, 5];
                    return [4, VSS.getService(VSS.ServiceIds.Dialog)];
                case 1:
                    dialogService = _a.sent();
                    _a.label = 2;
                case 2:
                    _a.trys.push([2, 4, , 5]);
                    return [4, dialogService.openMessageDialog(msg, { useBowtieStyle: true })];
                case 3:
                    _a.sent();
                    return [2, true];
                case 4:
                    e_1 = _a.sent();
                    return [2, false];
                case 5: return [2, true];
            }
        });
    });
}
export function showErrorDialog(message, reason) {
    return tslib_1.__awaiter(this, void 0, void 0, function () {
        var reasonStr, errorMsg, dialogService, e_2;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    reasonStr = typeof reason === "string" ? reason : reason && reason.message;
                    errorMsg = reasonStr ? message + " Reason: " + reasonStr : message;
                    return [4, VSS.getService(VSS.ServiceIds.Dialog)];
                case 1:
                    dialogService = _a.sent();
                    _a.label = 2;
                case 2:
                    _a.trys.push([2, 4, , 5]);
                    return [4, dialogService.openMessageDialog(errorMsg, { useBowtieStyle: true })];
                case 3:
                    _a.sent();
                    return [3, 5];
                case 4:
                    e_2 = _a.sent();
                    return [3, 5];
                case 5: return [2];
            }
        });
    });
}
//# sourceMappingURL=Core.js.map