import { isGuid } from "./Guid";
import { isNullOrWhiteSpace, startsWith } from "./String";
export function getCurrentUser(asIdentityRef) {
    var currentUser = VSS.getWebContext().user;
    if (asIdentityRef) {
        return {
            id: currentUser.id,
            displayName: currentUser.name,
            uniqueName: currentUser.uniqueName || currentUser.email,
            imageUrl: currentUser.id ? VSS.getWebContext().host.uri + "/_api/_common/IdentityImage?id=" + currentUser.id : null
        };
    }
    return currentUser.name + " <" + (currentUser.id || "") + ";" + (currentUser.uniqueName || "") + ">";
}
export function getDistinctNameFromIdentityRef(identityRef, includeId) {
    if (identityRef == null) {
        return "";
    }
    var displayName = identityRef.displayName;
    var id = includeId ? identityRef.id : null;
    var uniqueName = identityRef.uniqueName;
    var alias;
    if (id && uniqueName) {
        alias = id + ";" + uniqueName;
    }
    else if (!id && uniqueName) {
        alias = "" + uniqueName;
    }
    else if (id && !uniqueName) {
        alias = "" + id;
    }
    else {
        alias = null;
    }
    if (alias) {
        return displayName + " <" + alias + ">";
    }
    else {
        return displayName;
    }
}
export function parseWorkItemIdentityName(distinctName) {
    if (isNullOrWhiteSpace(distinctName)) {
        return {
            id: null,
            displayName: null,
            uniqueName: null,
            imageUrl: null
        };
    }
    var i = distinctName.lastIndexOf("<");
    var j = distinctName.lastIndexOf(">");
    var displayName = distinctName;
    var uniqueName;
    var rightPart;
    var id;
    if (i >= 0 && j > i && j === distinctName.length - 1) {
        displayName = distinctName.substr(0, i).trim();
        rightPart = distinctName.substr(i + 1, j - i - 1).trim();
        var vsIdFromAlias = getVsIdFromGroupUniqueName(rightPart);
        if (rightPart.indexOf("@") !== -1 || rightPart.indexOf("\\") !== -1 || vsIdFromAlias || isGuid(rightPart)) {
            uniqueName = rightPart;
            if (vsIdFromAlias !== "") {
                id = vsIdFromAlias;
                uniqueName = null;
            }
        }
        else {
            displayName = distinctName;
        }
    }
    var imageUrl;
    if (id) {
        imageUrl = VSS.getWebContext().host.uri + "/_api/_common/IdentityImage?id=" + id;
    }
    else if (uniqueName) {
        imageUrl = VSS.getWebContext().host.uri + "/_api/_common/IdentityImage?identifier=" + uniqueName + "&identifierType=0";
    }
    return {
        id: id,
        displayName: displayName,
        uniqueName: uniqueName,
        imageUrl: imageUrl
    };
}
export function parseUniquefiedIdentityName(distinctName) {
    if (isNullOrWhiteSpace(distinctName)) {
        return {
            id: null,
            displayName: null,
            uniqueName: null,
            imageUrl: null
        };
    }
    var i = distinctName.lastIndexOf("<");
    var j = distinctName.lastIndexOf(">");
    var displayName = distinctName;
    var uniqueName;
    var id;
    if (i >= 0 && j > i && j === distinctName.length - 1) {
        displayName = distinctName.substr(0, i).trim();
        var rightPart = distinctName.substr(i + 1, j - i - 1).trim();
        var idAndUniqueName = parseIdAndUniqueName(rightPart);
        id = idAndUniqueName.id;
        uniqueName = idAndUniqueName.uniqueName;
    }
    var imageUrl;
    if (id) {
        imageUrl = VSS.getWebContext().host.uri + "/_api/_common/IdentityImage?id=" + id;
    }
    else if (uniqueName) {
        imageUrl = VSS.getWebContext().host.uri + "/_api/_common/IdentityImage?identifier=" + uniqueName + "&identifierType=0";
    }
    return {
        id: id,
        displayName: displayName,
        uniqueName: uniqueName,
        imageUrl: imageUrl
    };
}
function getVsIdFromGroupUniqueName(str) {
    var leftPart;
    if (isNullOrWhiteSpace(str)) {
        return "";
    }
    var vsid = null;
    var i = str.lastIndexOf("\\");
    if (i === -1) {
        leftPart = str;
    }
    else {
        leftPart = str.substr(0, i);
    }
    if (startsWith(leftPart, "id:")) {
        var rightPart = leftPart.substr(3).trim();
        vsid = isGuid(rightPart) ? rightPart : "";
    }
    return vsid;
}
function parseIdAndUniqueName(str) {
    if (isNullOrWhiteSpace(str)) {
        return { id: null, uniqueName: null };
    }
    var parts = str.split(";");
    if (parts.length === 1) {
        if (isGuid(parts[0])) {
            return { id: parts[0], uniqueName: null };
        }
        return { id: null, uniqueName: parts[0] };
    }
    else {
        return { id: parts[0], uniqueName: parts[1] };
    }
}
//# sourceMappingURL=Identity.js.map