import { format } from "./Date";
function convertToString(value, upperCase, useLocale) {
    var result;
    if (value === null || value === undefined) {
        return "";
    }
    result = useLocale ? value.toLocaleString() : value.toString();
    if (upperCase) {
        result = useLocale ? result.toLocaleUpperCase() : result.toUpperCase();
    }
    return result;
}
export function isNullOrWhiteSpace(str) {
    return str == null || str.trim() === "";
}
export function isNullOrEmpty(str) {
    return str == null || str === "";
}
export function defaultComparer(a, b) {
    if (a === b) {
        return 0;
    }
    var a1 = convertToString(a, false, false);
    var b1 = convertToString(b, false, false);
    if (a1 === b1) {
        return 0;
    }
    else if (a1 > b1) {
        return 1;
    }
    else {
        return -1;
    }
}
export function ignoreCaseComparer(a, b) {
    if (a === b) {
        return 0;
    }
    var a1 = convertToString(a, true, false);
    var b1 = convertToString(b, true, false);
    if (a1 === b1) {
        return 0;
    }
    else if (a1 > b1) {
        return 1;
    }
    else {
        return -1;
    }
}
export function localeComparer(a, b) {
    if (a === b) {
        return 0;
    }
    var a1 = convertToString(a, false, true);
    var b1 = convertToString(b, false, true);
    return a1.localeCompare(b1);
}
export function localeIgnoreCaseComparer(a, b) {
    if (a === b) {
        return 0;
    }
    var a1 = convertToString(a, true, true);
    var b1 = convertToString(b, true, true);
    return a1.localeCompare(b1);
}
export function stringEquals(a, b, ignoreCase) {
    if (ignoreCase === void 0) { ignoreCase = false; }
    if (ignoreCase) {
        return localeIgnoreCaseComparer(a, b) === 0;
    }
    else {
        return localeComparer(a, b) === 0;
    }
}
export function startsWith(str, prefix, comparer) {
    comparer = comparer || defaultComparer;
    return comparer(prefix, str.substr(0, prefix.length)) === 0;
}
export function endsWith(str, suffix, comparer) {
    comparer = comparer || defaultComparer;
    return comparer(suffix, str.substr(str.length - suffix.length, suffix.length)) === 0;
}
export function caseInsensitiveContains(str, subStr) {
    return (str.toLowerCase().indexOf(subStr.toLowerCase()) !== -1);
}
export function toString(val) {
    if (typeof (val) === "boolean") {
        return val ? "True" : "False";
    }
    else if (typeof (val) === "number") {
        return "" + val;
    }
    else if (val instanceof Date) {
        format(val);
    }
    else {
        return val;
    }
}
export function hashCode(str) {
    if (isNullOrWhiteSpace(str)) {
        return 0;
    }
    var hash = 0;
    var trimmedString = str.trim();
    for (var i = 0; i < trimmedString.length; i++) {
        var ch = str.charCodeAt(i);
        hash = ((hash << 5) - hash) + ch;
        hash = hash & hash;
    }
    return hash;
}
//# sourceMappingURL=String.js.map